@@ -6,9 +6,9 @@ from addthis.api import Addthis
 from addthis.exceptions import AddthisError, AddthisValidationError
 
 __author__ = 'Alex Parinov'
-__author_email__ = 'creafz@gmail.com'
+__email__ = 'creafz@gmail.com'
 __license__ = 'MIT'
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 __all__ = [
     '__author__',
